Documentation
¶
Index ¶
- Variables
- type SimpleStorage
- type SimpleStorageCaller
- type SimpleStorageCallerRaw
- type SimpleStorageCallerSession
- type SimpleStorageFilterer
- func (_SimpleStorage *SimpleStorageFilterer) FilterValueIncremented(opts *bind.FilterOpts, incrementer []common.Address) (*SimpleStorageValueIncrementedIterator, error)
- func (_SimpleStorage *SimpleStorageFilterer) FilterValueSet(opts *bind.FilterOpts, setter []common.Address) (*SimpleStorageValueSetIterator, error)
- func (_SimpleStorage *SimpleStorageFilterer) ParseValueIncremented(log types.Log) (*SimpleStorageValueIncremented, error)
- func (_SimpleStorage *SimpleStorageFilterer) ParseValueSet(log types.Log) (*SimpleStorageValueSet, error)
- func (_SimpleStorage *SimpleStorageFilterer) WatchValueIncremented(opts *bind.WatchOpts, sink chan<- *SimpleStorageValueIncremented, ...) (event.Subscription, error)
- func (_SimpleStorage *SimpleStorageFilterer) WatchValueSet(opts *bind.WatchOpts, sink chan<- *SimpleStorageValueSet, ...) (event.Subscription, error)
- type SimpleStorageRaw
- func (_SimpleStorage *SimpleStorageRaw) Call(opts *bind.CallOpts, result *[]interface{}, method string, ...) error
- func (_SimpleStorage *SimpleStorageRaw) Transact(opts *bind.TransactOpts, method string, params ...interface{}) (*types.Transaction, error)
- func (_SimpleStorage *SimpleStorageRaw) Transfer(opts *bind.TransactOpts) (*types.Transaction, error)
- type SimpleStorageSession
- func (_SimpleStorage *SimpleStorageSession) GetValue() (*big.Int, error)
- func (_SimpleStorage *SimpleStorageSession) Increment() (*types.Transaction, error)
- func (_SimpleStorage *SimpleStorageSession) IncrementBy(_amount *big.Int) (*types.Transaction, error)
- func (_SimpleStorage *SimpleStorageSession) Owner() (common.Address, error)
- func (_SimpleStorage *SimpleStorageSession) SetValue(_value *big.Int) (*types.Transaction, error)
- type SimpleStorageTransactor
- func (_SimpleStorage *SimpleStorageTransactor) Increment(opts *bind.TransactOpts) (*types.Transaction, error)
- func (_SimpleStorage *SimpleStorageTransactor) IncrementBy(opts *bind.TransactOpts, _amount *big.Int) (*types.Transaction, error)
- func (_SimpleStorage *SimpleStorageTransactor) SetValue(opts *bind.TransactOpts, _value *big.Int) (*types.Transaction, error)
- type SimpleStorageTransactorRaw
- type SimpleStorageTransactorSession
- func (_SimpleStorage *SimpleStorageTransactorSession) Increment() (*types.Transaction, error)
- func (_SimpleStorage *SimpleStorageTransactorSession) IncrementBy(_amount *big.Int) (*types.Transaction, error)
- func (_SimpleStorage *SimpleStorageTransactorSession) SetValue(_value *big.Int) (*types.Transaction, error)
- type SimpleStorageValueIncremented
- type SimpleStorageValueIncrementedIterator
- type SimpleStorageValueSet
- type SimpleStorageValueSetIterator
Constants ¶
This section is empty.
Variables ¶
var SimpleStorageABI = SimpleStorageMetaData.ABI
SimpleStorageABI is the input ABI used to generate the binding from. Deprecated: Use SimpleStorageMetaData.ABI instead.
var SimpleStorageBin = SimpleStorageMetaData.Bin
SimpleStorageBin is the compiled bytecode used for deploying new contracts. Deprecated: Use SimpleStorageMetaData.Bin instead.
var SimpleStorageMetaData = &bind.MetaData{
ABI: "[{\"inputs\":[{\"internalType\":\"uint256\",\"name\":\"_initialValue\",\"type\":\"uint256\"}],\"stateMutability\":\"nonpayable\",\"type\":\"constructor\"},{\"anonymous\":false,\"inputs\":[{\"indexed\":true,\"internalType\":\"address\",\"name\":\"incrementer\",\"type\":\"address\"},{\"indexed\":false,\"internalType\":\"uint256\",\"name\":\"newValue\",\"type\":\"uint256\"}],\"name\":\"ValueIncremented\",\"type\":\"event\"},{\"anonymous\":false,\"inputs\":[{\"indexed\":true,\"internalType\":\"address\",\"name\":\"setter\",\"type\":\"address\"},{\"indexed\":false,\"internalType\":\"uint256\",\"name\":\"oldValue\",\"type\":\"uint256\"},{\"indexed\":false,\"internalType\":\"uint256\",\"name\":\"newValue\",\"type\":\"uint256\"}],\"name\":\"ValueSet\",\"type\":\"event\"},{\"inputs\":[],\"name\":\"getValue\",\"outputs\":[{\"internalType\":\"uint256\",\"name\":\"\",\"type\":\"uint256\"}],\"stateMutability\":\"view\",\"type\":\"function\"},{\"inputs\":[],\"name\":\"increment\",\"outputs\":[],\"stateMutability\":\"nonpayable\",\"type\":\"function\"},{\"inputs\":[{\"internalType\":\"uint256\",\"name\":\"_amount\",\"type\":\"uint256\"}],\"name\":\"incrementBy\",\"outputs\":[],\"stateMutability\":\"nonpayable\",\"type\":\"function\"},{\"inputs\":[],\"name\":\"owner\",\"outputs\":[{\"internalType\":\"address\",\"name\":\"\",\"type\":\"address\"}],\"stateMutability\":\"view\",\"type\":\"function\"},{\"inputs\":[{\"internalType\":\"uint256\",\"name\":\"_value\",\"type\":\"uint256\"}],\"name\":\"setValue\",\"outputs\":[],\"stateMutability\":\"nonpayable\",\"type\":\"function\"}]",
Bin: "0x608060405234801561000f575f80fd5b506040516102cb3803806102cb83398101604081905261002e91610088565b5f818155600180546001600160a01b03191633908117909155604080519283526020830184905290917fc0e9036d619701c94569e1462d8120ef4a6d2b15a70d27cc942fd29ae2cc0e59910160405180910390a25061009f565b5f60208284031215610098575f80fd5b5051919050565b61021f806100ac5f395ff3fe608060405234801561000f575f80fd5b5060043610610055575f3560e01c806303df179c14610059578063209652551461006e57806355241077146100835780638da5cb5b14610096578063d09de08a146100c1575b5f80fd5b61006c6100673660046101ad565b6100c9565b005b5f546040519081526020015b60405180910390f35b61006c6100913660046101ad565b610118565b6001546100a9906001600160a01b031681565b6040516001600160a01b03909116815260200161007a565b61006c61015e565b805f808282546100d991906101c4565b90915550505f5460405190815233907fa21dda55b1348fedf9117958d187753c14c74e506bd79a71c7ba6b52ebe71c419060200160405180910390a250565b5f805490829055604080518281526020810184905233917fc0e9036d619701c94569e1462d8120ef4a6d2b15a70d27cc942fd29ae2cc0e59910160405180910390a25050565b60015f8082825461016f91906101c4565b90915550505f5460405190815233907fa21dda55b1348fedf9117958d187753c14c74e506bd79a71c7ba6b52ebe71c419060200160405180910390a2565b5f602082840312156101bd575f80fd5b5035919050565b808201808211156101e357634e487b7160e01b5f52601160045260245ffd5b9291505056fea2646970667358221220a1b8b6939f49320f465f0e3b759f6eeb0b4f930ee31fa22c05327b950c64794f64736f6c63430008160033",
}
SimpleStorageMetaData contains all meta data concerning the SimpleStorage contract.
Functions ¶
This section is empty.
Types ¶
type SimpleStorage ¶
type SimpleStorage struct {
SimpleStorageCaller // Read-only binding to the contract
SimpleStorageTransactor // Write-only binding to the contract
SimpleStorageFilterer // Log filterer for contract events
}
SimpleStorage is an auto generated Go binding around an Ethereum contract.
func DeploySimpleStorage ¶
func DeploySimpleStorage(auth *bind.TransactOpts, backend bind.ContractBackend, _initialValue *big.Int) (common.Address, *types.Transaction, *SimpleStorage, error)
DeploySimpleStorage deploys a new Ethereum contract, binding an instance of SimpleStorage to it.
func NewSimpleStorage ¶
func NewSimpleStorage(address common.Address, backend bind.ContractBackend) (*SimpleStorage, error)
NewSimpleStorage creates a new instance of SimpleStorage, bound to a specific deployed contract.
type SimpleStorageCaller ¶
type SimpleStorageCaller struct {
// contains filtered or unexported fields
}
SimpleStorageCaller is an auto generated read-only Go binding around an Ethereum contract.
func NewSimpleStorageCaller ¶
func NewSimpleStorageCaller(address common.Address, caller bind.ContractCaller) (*SimpleStorageCaller, error)
NewSimpleStorageCaller creates a new read-only instance of SimpleStorage, bound to a specific deployed contract.
type SimpleStorageCallerRaw ¶
type SimpleStorageCallerRaw struct {
Contract *SimpleStorageCaller // Generic read-only contract binding to access the raw methods on
}
SimpleStorageCallerRaw is an auto generated low-level read-only Go binding around an Ethereum contract.
func (*SimpleStorageCallerRaw) Call ¶
func (_SimpleStorage *SimpleStorageCallerRaw) Call(opts *bind.CallOpts, result *[]interface{}, method string, params ...interface{}) error
Call invokes the (constant) contract method with params as input values and sets the output to result. The result type might be a single field for simple returns, a slice of interfaces for anonymous returns and a struct for named returns.
type SimpleStorageCallerSession ¶
type SimpleStorageCallerSession struct {
Contract *SimpleStorageCaller // Generic contract caller binding to set the session for
CallOpts bind.CallOpts // Call options to use throughout this session
}
SimpleStorageCallerSession is an auto generated read-only Go binding around an Ethereum contract, with pre-set call options.
type SimpleStorageFilterer ¶
type SimpleStorageFilterer struct {
// contains filtered or unexported fields
}
SimpleStorageFilterer is an auto generated log filtering Go binding around an Ethereum contract events.
func NewSimpleStorageFilterer ¶
func NewSimpleStorageFilterer(address common.Address, filterer bind.ContractFilterer) (*SimpleStorageFilterer, error)
NewSimpleStorageFilterer creates a new log filterer instance of SimpleStorage, bound to a specific deployed contract.
func (*SimpleStorageFilterer) FilterValueIncremented ¶
func (_SimpleStorage *SimpleStorageFilterer) FilterValueIncremented(opts *bind.FilterOpts, incrementer []common.Address) (*SimpleStorageValueIncrementedIterator, error)
FilterValueIncremented is a free log retrieval operation binding the contract event 0xa21dda55b1348fedf9117958d187753c14c74e506bd79a71c7ba6b52ebe71c41.
Solidity: event ValueIncremented(address indexed incrementer, uint256 newValue)
func (*SimpleStorageFilterer) FilterValueSet ¶
func (_SimpleStorage *SimpleStorageFilterer) FilterValueSet(opts *bind.FilterOpts, setter []common.Address) (*SimpleStorageValueSetIterator, error)
FilterValueSet is a free log retrieval operation binding the contract event 0xc0e9036d619701c94569e1462d8120ef4a6d2b15a70d27cc942fd29ae2cc0e59.
Solidity: event ValueSet(address indexed setter, uint256 oldValue, uint256 newValue)
func (*SimpleStorageFilterer) ParseValueIncremented ¶
func (_SimpleStorage *SimpleStorageFilterer) ParseValueIncremented(log types.Log) (*SimpleStorageValueIncremented, error)
ParseValueIncremented is a log parse operation binding the contract event 0xa21dda55b1348fedf9117958d187753c14c74e506bd79a71c7ba6b52ebe71c41.
Solidity: event ValueIncremented(address indexed incrementer, uint256 newValue)
func (*SimpleStorageFilterer) ParseValueSet ¶
func (_SimpleStorage *SimpleStorageFilterer) ParseValueSet(log types.Log) (*SimpleStorageValueSet, error)
ParseValueSet is a log parse operation binding the contract event 0xc0e9036d619701c94569e1462d8120ef4a6d2b15a70d27cc942fd29ae2cc0e59.
Solidity: event ValueSet(address indexed setter, uint256 oldValue, uint256 newValue)
func (*SimpleStorageFilterer) WatchValueIncremented ¶
func (_SimpleStorage *SimpleStorageFilterer) WatchValueIncremented(opts *bind.WatchOpts, sink chan<- *SimpleStorageValueIncremented, incrementer []common.Address) (event.Subscription, error)
WatchValueIncremented is a free log subscription operation binding the contract event 0xa21dda55b1348fedf9117958d187753c14c74e506bd79a71c7ba6b52ebe71c41.
Solidity: event ValueIncremented(address indexed incrementer, uint256 newValue)
func (*SimpleStorageFilterer) WatchValueSet ¶
func (_SimpleStorage *SimpleStorageFilterer) WatchValueSet(opts *bind.WatchOpts, sink chan<- *SimpleStorageValueSet, setter []common.Address) (event.Subscription, error)
WatchValueSet is a free log subscription operation binding the contract event 0xc0e9036d619701c94569e1462d8120ef4a6d2b15a70d27cc942fd29ae2cc0e59.
Solidity: event ValueSet(address indexed setter, uint256 oldValue, uint256 newValue)
type SimpleStorageRaw ¶
type SimpleStorageRaw struct {
Contract *SimpleStorage // Generic contract binding to access the raw methods on
}
SimpleStorageRaw is an auto generated low-level Go binding around an Ethereum contract.
func (*SimpleStorageRaw) Call ¶
func (_SimpleStorage *SimpleStorageRaw) Call(opts *bind.CallOpts, result *[]interface{}, method string, params ...interface{}) error
Call invokes the (constant) contract method with params as input values and sets the output to result. The result type might be a single field for simple returns, a slice of interfaces for anonymous returns and a struct for named returns.
func (*SimpleStorageRaw) Transact ¶
func (_SimpleStorage *SimpleStorageRaw) Transact(opts *bind.TransactOpts, method string, params ...interface{}) (*types.Transaction, error)
Transact invokes the (paid) contract method with params as input values.
func (*SimpleStorageRaw) Transfer ¶
func (_SimpleStorage *SimpleStorageRaw) Transfer(opts *bind.TransactOpts) (*types.Transaction, error)
Transfer initiates a plain transaction to move funds to the contract, calling its default method if one is available.
type SimpleStorageSession ¶
type SimpleStorageSession struct {
Contract *SimpleStorage // Generic contract binding to set the session for
CallOpts bind.CallOpts // Call options to use throughout this session
TransactOpts bind.TransactOpts // Transaction auth options to use throughout this session
}
SimpleStorageSession is an auto generated Go binding around an Ethereum contract, with pre-set call and transact options.
func (*SimpleStorageSession) GetValue ¶
func (_SimpleStorage *SimpleStorageSession) GetValue() (*big.Int, error)
GetValue is a free data retrieval call binding the contract method 0x20965255.
Solidity: function getValue() view returns(uint256)
func (*SimpleStorageSession) Increment ¶
func (_SimpleStorage *SimpleStorageSession) Increment() (*types.Transaction, error)
Increment is a paid mutator transaction binding the contract method 0xd09de08a.
Solidity: function increment() returns()
func (*SimpleStorageSession) IncrementBy ¶
func (_SimpleStorage *SimpleStorageSession) IncrementBy(_amount *big.Int) (*types.Transaction, error)
IncrementBy is a paid mutator transaction binding the contract method 0x03df179c.
Solidity: function incrementBy(uint256 _amount) returns()
func (*SimpleStorageSession) Owner ¶
func (_SimpleStorage *SimpleStorageSession) Owner() (common.Address, error)
Owner is a free data retrieval call binding the contract method 0x8da5cb5b.
Solidity: function owner() view returns(address)
func (*SimpleStorageSession) SetValue ¶
func (_SimpleStorage *SimpleStorageSession) SetValue(_value *big.Int) (*types.Transaction, error)
SetValue is a paid mutator transaction binding the contract method 0x55241077.
Solidity: function setValue(uint256 _value) returns()
type SimpleStorageTransactor ¶
type SimpleStorageTransactor struct {
// contains filtered or unexported fields
}
SimpleStorageTransactor is an auto generated write-only Go binding around an Ethereum contract.
func NewSimpleStorageTransactor ¶
func NewSimpleStorageTransactor(address common.Address, transactor bind.ContractTransactor) (*SimpleStorageTransactor, error)
NewSimpleStorageTransactor creates a new write-only instance of SimpleStorage, bound to a specific deployed contract.
func (*SimpleStorageTransactor) Increment ¶
func (_SimpleStorage *SimpleStorageTransactor) Increment(opts *bind.TransactOpts) (*types.Transaction, error)
Increment is a paid mutator transaction binding the contract method 0xd09de08a.
Solidity: function increment() returns()
func (*SimpleStorageTransactor) IncrementBy ¶
func (_SimpleStorage *SimpleStorageTransactor) IncrementBy(opts *bind.TransactOpts, _amount *big.Int) (*types.Transaction, error)
IncrementBy is a paid mutator transaction binding the contract method 0x03df179c.
Solidity: function incrementBy(uint256 _amount) returns()
func (*SimpleStorageTransactor) SetValue ¶
func (_SimpleStorage *SimpleStorageTransactor) SetValue(opts *bind.TransactOpts, _value *big.Int) (*types.Transaction, error)
SetValue is a paid mutator transaction binding the contract method 0x55241077.
Solidity: function setValue(uint256 _value) returns()
type SimpleStorageTransactorRaw ¶
type SimpleStorageTransactorRaw struct {
Contract *SimpleStorageTransactor // Generic write-only contract binding to access the raw methods on
}
SimpleStorageTransactorRaw is an auto generated low-level write-only Go binding around an Ethereum contract.
func (*SimpleStorageTransactorRaw) Transact ¶
func (_SimpleStorage *SimpleStorageTransactorRaw) Transact(opts *bind.TransactOpts, method string, params ...interface{}) (*types.Transaction, error)
Transact invokes the (paid) contract method with params as input values.
func (*SimpleStorageTransactorRaw) Transfer ¶
func (_SimpleStorage *SimpleStorageTransactorRaw) Transfer(opts *bind.TransactOpts) (*types.Transaction, error)
Transfer initiates a plain transaction to move funds to the contract, calling its default method if one is available.
type SimpleStorageTransactorSession ¶
type SimpleStorageTransactorSession struct {
Contract *SimpleStorageTransactor // Generic contract transactor binding to set the session for
TransactOpts bind.TransactOpts // Transaction auth options to use throughout this session
}
SimpleStorageTransactorSession is an auto generated write-only Go binding around an Ethereum contract, with pre-set transact options.
func (*SimpleStorageTransactorSession) Increment ¶
func (_SimpleStorage *SimpleStorageTransactorSession) Increment() (*types.Transaction, error)
Increment is a paid mutator transaction binding the contract method 0xd09de08a.
Solidity: function increment() returns()
func (*SimpleStorageTransactorSession) IncrementBy ¶
func (_SimpleStorage *SimpleStorageTransactorSession) IncrementBy(_amount *big.Int) (*types.Transaction, error)
IncrementBy is a paid mutator transaction binding the contract method 0x03df179c.
Solidity: function incrementBy(uint256 _amount) returns()
func (*SimpleStorageTransactorSession) SetValue ¶
func (_SimpleStorage *SimpleStorageTransactorSession) SetValue(_value *big.Int) (*types.Transaction, error)
SetValue is a paid mutator transaction binding the contract method 0x55241077.
Solidity: function setValue(uint256 _value) returns()
type SimpleStorageValueIncremented ¶
type SimpleStorageValueIncremented struct {
Incrementer common.Address
NewValue *big.Int
Raw types.Log // Blockchain specific contextual infos
}
SimpleStorageValueIncremented represents a ValueIncremented event raised by the SimpleStorage contract.
type SimpleStorageValueIncrementedIterator ¶
type SimpleStorageValueIncrementedIterator struct {
Event *SimpleStorageValueIncremented // Event containing the contract specifics and raw log
// contains filtered or unexported fields
}
SimpleStorageValueIncrementedIterator is returned from FilterValueIncremented and is used to iterate over the raw logs and unpacked data for ValueIncremented events raised by the SimpleStorage contract.
func (*SimpleStorageValueIncrementedIterator) Close ¶
func (it *SimpleStorageValueIncrementedIterator) Close() error
Close terminates the iteration process, releasing any pending underlying resources.
func (*SimpleStorageValueIncrementedIterator) Error ¶
func (it *SimpleStorageValueIncrementedIterator) Error() error
Error returns any retrieval or parsing error occurred during filtering.
func (*SimpleStorageValueIncrementedIterator) Next ¶
func (it *SimpleStorageValueIncrementedIterator) Next() bool
Next advances the iterator to the subsequent event, returning whether there are any more events found. In case of a retrieval or parsing error, false is returned and Error() can be queried for the exact failure.
type SimpleStorageValueSet ¶
type SimpleStorageValueSet struct {
Setter common.Address
OldValue *big.Int
NewValue *big.Int
Raw types.Log // Blockchain specific contextual infos
}
SimpleStorageValueSet represents a ValueSet event raised by the SimpleStorage contract.
type SimpleStorageValueSetIterator ¶
type SimpleStorageValueSetIterator struct {
Event *SimpleStorageValueSet // Event containing the contract specifics and raw log
// contains filtered or unexported fields
}
SimpleStorageValueSetIterator is returned from FilterValueSet and is used to iterate over the raw logs and unpacked data for ValueSet events raised by the SimpleStorage contract.
func (*SimpleStorageValueSetIterator) Close ¶
func (it *SimpleStorageValueSetIterator) Close() error
Close terminates the iteration process, releasing any pending underlying resources.
func (*SimpleStorageValueSetIterator) Error ¶
func (it *SimpleStorageValueSetIterator) Error() error
Error returns any retrieval or parsing error occurred during filtering.
func (*SimpleStorageValueSetIterator) Next ¶
func (it *SimpleStorageValueSetIterator) Next() bool
Next advances the iterator to the subsequent event, returning whether there are any more events found. In case of a retrieval or parsing error, false is returned and Error() can be queried for the exact failure.